==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/da.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakter",
    "Address book name" : "Adressebogsnavn",
    "Import" : "Importér",
    "The selected image is too big (max 1MB)" : "Det valgte billede er for stort (max 1MB)",
    "No contacts in here" : "Ingen kontaktpersoner her",
    "Name" : "Navn",
    "Organization" : "Organisation",
    "Title" : "Titel",
    "Add field ..." : "Tilføj felt...",
    "+ New contact" : "Tilføj ny kontaktperson",
    "No search result for {query}" : "Ingen søgeresultater for  {query}",
    "_%n contact_::_%n contacts_" : ["%n kontaktperson","%n kontaktpersoner"],
    "Post office box" : "Postboks",
    "Postal code" : "Postnummer",
    "City" : "By",
    "State or province" : "Stat eller provins",
    "Country" : "Land",
    "Address" : "Adresse",
    "(new group)" : "(new group)",
    "Last name" : "Efternavn",
    "First name" : "Fornavn",
    "Additional names" : "Mellemnavne",
    "Prefix" : "Præfiks",
    "Suffix" : "Suffiks",
    "All contacts" : "Alle kontakter",
    "Not grouped" : "Ikke i gruppe",
    "New contact" : "Ny kontakt",
    "{addressbook} shared by {owner}" : "{addressbook} delt af {owner}",
    "No contacts in file. Only VCard files are allowed." : "Ingen kontakter i filen. Kun vCard filer accepteres.",
    "Nickname" : "Kaldenavn",
    "Detailed name" : "Detaljeret navn",
    "Notes" : "Noter",
    "Website" : "Hjemmeside",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Hjemme",
    "Work" : "Arbejde",
    "Other" : "Andet",
    "Groups" : "Grupper",
    "Birthday" : "Fødselsdag",
    "Anniversary" : "Årsdag",
    "Date of death" : "Dødsdato",
    "Email" : "E-mail",
    "Instant messaging" : "Instant Messaging",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax hjemme",
    "Fax work" : "Fax arbejde",
    "Pager" : "Personsøger",
    "Voice" : "Telefonsvarer",
    "Social network" : "Socialt netværk",
    "Settings" : "Indstillinger"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-contacts-2%3A1.5.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/da.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakter",
    "Download" : "Hent",
    "Share with users or groups" : "Del med brugere eller grupper",
    "Delete" : "Slet",
    "can edit" : "kan redigere",
    "Address book name" : "Adressebogsnavn",
    "Import" : "Importér",
    "The selected image is too big (max 1MB)" : "Det valgte billede er for stort (max 1MB)",
    "No contacts in here" : "Ingen kontaktpersoner her",
    "Name" : "Navn",
    "Organization" : "Organisation",
    "Title" : "Titel",
    "Add field ..." : "Tilføj felt...",
    "No search result for {query}" : "Ingen søgeresultater for  {query}",
    "_%n contact_::_%n contacts_" : ["%n kontaktperson","%n kontaktpersoner"],
    "Post office box" : "Postboks",
    "Postal code" : "Postnummer",
    "City" : "By",
    "State or province" : "Stat eller provins",
    "Country" : "Land",
    "Address" : "Adresse",
    "(new group)" : "(new group)",
    "Last name" : "Efternavn",
    "First name" : "Fornavn",
    "Additional names" : "Mellemnavne",
    "Prefix" : "Præfiks",
    "Suffix" : "Suffiks",
    "All contacts" : "Alle kontakter",
    "Not grouped" : "Ikke i gruppe",
    "New contact" : "Ny kontakt",
    "{addressbook} shared by {owner}" : "{addressbook} delt af {owner}",
    "Contact could not be created." : "Kontakt kunne ikke oprettes.",
    "No contacts in file. Only VCard files are allowed." : "Ingen kontakter i filen. Kun vCard filer accepteres.",
    "Nickname" : "Kaldenavn",
    "Detailed name" : "Detaljeret navn",
    "Notes" : "Noter",
    "Website" : "Hjemmeside",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Hjemme",
    "Work" : "Arbejde",
    "Other" : "Andet",
    "Groups" : "Grupper",
    "Birthday" : "Fødselsdag",
    "Anniversary" : "Årsdag",
    "Date of death" : "Dødsdato",
    "Email" : "E-mail",
    "Instant messaging" : "Instant Messaging",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax hjemme",
    "Fax work" : "Fax arbejde",
    "Pager" : "Personsøger",
    "Voice" : "Telefonsvarer",
    "Social network" : "Socialt netværk",
    "Settings" : "Indstillinger"
},
"nplurals=2; plural=(n != 1);");
